// -*- C++ -*-
#include "tao/Collocation_Resolver.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_Collocation_Resolver::~TAO_Collocation_Resolver ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
